export type UseAsyncProps<ExecPayload = any, ResultSchema = any> = {
    fn: (props: ExecPayload) => Promise<ResultSchema>;
    autoExec?: boolean;
    throwErrorOnExecFail?: boolean;
    defaultData?: ResultSchema;
    defaultPayload?: ExecPayload;
    additionalPayload?: ExecPayload;
    onResult?: (props: {
        result: ResultSchema;
    }) => any;
    onError?: (props: {
        error: Error | string;
        fnProps: ExecPayload;
    }) => any;
    onLoading?: (props: {
        loading: boolean;
    }) => any;
};
export type UseAsyncReturn<ExecPayload = any, ResultSchema = any> = {
    loading: boolean;
    error: Error | string | null;
    result: ResultSchema;
    exec: (payload?: ExecPayload | undefined) => Promise<{
        result: ResultSchema | undefined;
        error: Error | undefined;
    } | null>;
    publicErrorMessage: string | null;
};
/**
 * @example
 * const promise = useAsync({
 * fn
 * })
 */
export default function useAsync<ExecPayload, ResultSchema>({ fn, autoExec, throwErrorOnExecFail, defaultData, defaultPayload, additionalPayload, onResult, onError, onLoading, }: UseAsyncProps<ExecPayload, ResultSchema>): UseAsyncReturn<ExecPayload, ResultSchema>;
